@@ -1,14 +1,12 @@
 ## File Name: BIFIE.derivedParameters.R
-## File Version: 0.29
+## File Version: 0.380
 
-####################################################
-# statistical inference for derived parameters
+
+#--- statistical inference for derived parameters
 BIFIE.derivedParameters <- function( BIFIE.method, derived.parameters, type=NULL )
 {
-
     cl <- match.call()
     s1 <- Sys.time()
-
     object <- res1 <- BIFIE.method
     parnames <- res1$parnames
     Nimp <- res1$Nimp
@@ -16,14 +14,12 @@ BIFIE.derivedParameters <- function( BIFIE.method, derived.parameters, type=NULL
 
     # extract replicated parameters
     parsres <- extract.replicated.pars( BIFIE.method=res1, type=type )
-
-    #*****
     pars0 <- parsres$parsM
     pars0.rep <- parsres$parsrepM
     rownames(pars0) <- parnames
     rownames(pars0.rep) <- parnames
 
-    ###########################
+    #- handle formulas
     allformulas <- derived.parameters[[1]]
     FF <- length(derived.parameters)
     if (FF>1){
@@ -41,17 +37,18 @@ BIFIE.derivedParameters <- function( BIFIE.method, derived.parameters, type=NULL
     colnames(der.pars.rep) <- names(derived.parameters)
     fayfac <- res1$fayfac
     NP <- ncol(der.pars)
-    Cdes <- matrix( 1, ncol=NP, nrow=1 )
+    Cdes <- diag(NP)
     Ccols <- which( colSums( abs( Cdes) ) > 0 )
     parsM <- as.matrix( t( der.pars ) )
     parsrepM <- as.matrix( t( der.pars.rep ) )
-    rdes <- c(0)
-    # compute covariance matrices
-    # Function for (ordinary) multiple imputation
-
-    res0 <- bifie_waldtest(  parsM, parsrepM,
-                        Cdes, rdes, Ccols - 1, fayfac )
+    rdes <- rep(0,NP)
 
+    #- global Wald test
+    res0 <- res <- bifiesurvey_rcpp_wald_test( parsM=parsM, parsrepM=parsrepM,
+                        Cdes=Cdes, rdes=rdes, Ccols=Ccols-1, fayfac=fayfac )
+    res_wald <- data.frame( "D1"=res$D1, "D2"=res$D2, "df1"=res$df,
+                "D1_df2"=round(res$nu2,1), "D2_df2"=round(res$nu3,1),
+                "D1_p"=res$p_D1, "D2_p"=res$p_D2 )
     var_w <- res0$var_w
     var_b <- res0$var_b
     # total variance
@@ -64,7 +61,6 @@ BIFIE.derivedParameters <- function( BIFIE.method, derived.parameters, type=NULL
     eps <- 1E-10
     stat$t <- stat$coef / stat$se
     stat$df <- rubin_calc_df2( B=diag(var_b), W=diag(var_w), Nimp, digits=2)
-#    stat$p <- 2* pnorm( - abs( stat$t ) )
     stat$p <- 2*stats::pt( - abs(stat$t), df=stat$df )
     stat$fmi <-  ( 1+1/Nimp) * diag(var_b) / ( stat$se^2 + eps )
     stat$VarMI <- diag( var_b )
@@ -81,7 +77,7 @@ BIFIE.derivedParameters <- function( BIFIE.method, derived.parameters, type=NULL
         stat$t <- res0$pars / res0$pars_se
         stat$p <- 2*stats::pt( - abs(stat$t), df=stat$df )
         stat$fmi <- res0$pars_fmi
-        stat$VarMI <- res0$pars_varBetween1 +    res0$pars_varBetween2
+        stat$VarMI <- res0$pars_varBetween1 + res0$pars_varBetween2
         stat$fmi_St1 <- res0$pars_fmiB
         stat$fmi_St2 <- res0$pars_fmiW
     }
@@ -89,36 +85,39 @@ BIFIE.derivedParameters <- function( BIFIE.method, derived.parameters, type=NULL
     s2 <- Sys.time()
     timediff <- c( s1, s2 ) #, paste(s2-s1 ) )
     res <- list( "stat"=stat, "coef"=rowMeans( parsM ),
-                "se"=sqrt( diag( var_tot ) ),
+                "se"=sqrt(diag(var_tot)),
                 "vcov"=var_tot, "Nimp"=Nimp, "fayfac"=fayfac,
                 "N"=res1$N, "RR"=res1$RR,
                 "NMI"=BIFIE.method$NMI, "Nimp_NMI"=BIFIE.method$Nimp_NMI,
                 "allformulas"=allformulas, "CALL"=cl,
-                "timediff"=timediff     ,
+                "timediff"=timediff,
                 "derived.parameters"=derived.parameters,
                 "parsM"=parsM, parsrepM=parsrepM,
-                "parnames"=names(derived.parameters)
+                "parnames"=names(derived.parameters), res_wald=res_wald
                         )
     class(res) <- "BIFIE.derivedParameters"
     return(res)
-    }
-#########################################################
+}
 
-####################################################################################
-# summary for BIFIE.derivedParameters function
+
+#--- summary for BIFIE.derivedParameters function
 summary.BIFIE.derivedParameters <- function( object, digits=4, ... )
 {
     BIFIE.summary(object)
     cat("Formulas for Derived Parameters \n\n")
     FF <- length( object$derived.parameters)
     for (ff in 1:FF){
-        cat( paste0(  object$parnames[ff], " :=",
+        cat( paste0(  object$parnames[ff], " :=", " ",
                     attr(  stats::terms( object$derived.parameters[[ff]] ), "term.labels" ),
                         collapse=" " ),
                                 "\n")
     }
-    #***
-    cat("\nStatistical Inference for Derived Parameters \n")
+    cat("\nStatistical Inference for Derived Parameters \n\n")
     obji <- object$stat
     print.object.summary( obji, digits=digits )
+
+    #- Wald test
+    cat("\n")
+    BIFIE_waldtest_summary_print_test_statistics(object=object, digits=digits,
+            value_name="res_wald")
 }
