@@ -1,5 +1,5 @@
 //// File Name: bifiesurvey_rcpp_helper.cpp
-//// File Version: 7.43
+//// File Version: 7.492
 
 
 // [[Rcpp::depends(RcppArmadillo)]]
@@ -15,271 +15,6 @@ using namespace Rcpp;
 using namespace arma;
 
 
-
-//***************************************
-// path model
-Rcpp::List bifie_pathmodel_helper( Rcpp::NumericMatrix dat1,
-    Rcpp::NumericMatrix wgt, Rcpp::NumericVector group_values,
-    Rcpp::NumericVector group_index1, Rcpp::NumericVector vars_index,
-    Rcpp::NumericMatrix R, int NP0, Rcpp::NumericMatrix coeff_index,
-    Rcpp::NumericMatrix E, Rcpp::NumericMatrix L, int NL,
-    Rcpp::NumericVector L_row_index, Rcpp::NumericVector R_row_index,
-    Rcpp::NumericVector unreliability )
-{
-
-    int N = dat1.nrow();
-    int GG = group_values.size();
-    int RR = wgt.ncol();
-    int VV = vars_index.size();
-
-    int group_index = group_index1[0];
-    Rcpp::NumericMatrix indcases(N,GG);
-    Rcpp::NumericVector ncases(GG);
-    Rcpp::NumericMatrix sumwgt1(GG,RR);
-    int WW = wgt.ncol();
-    int NR = R.nrow();
-
-    // parameter vector
-    int NP = 2*NP0 + 2*NR;
-    Rcpp::NumericMatrix parsM( GG*NP, WW );
-    int Npow = coeff_index.ncol();
-    int Nrci = coeff_index.nrow();
-
-    //**************************
-    // extract usable cases
-    for (int nn=0;nn<N;nn++){ // beg nn
-       for (int gg=0; gg < GG; gg++ ){  // beg gg
-        if ( dat1(nn,group_index) == group_values[gg] ){
-            indcases(nn,gg)=1;
-                    }
-        for (int vv=0;vv<VV;vv++){ // beg vv  independent vars
-           if (  R_IsNA( dat1(nn, vars_index[vv] ) ) ){
-            indcases(nn,gg)=0;
-                    }
-                } // end vv  independent vars
-        if ( indcases(nn,gg) == 1 ){
-            ncases[gg] ++;
-            for (int ww=0;ww<WW; ww++){
-                sumwgt1(gg,ww) += wgt(nn,ww);
-                }
-            break;
-                }
-            }   // end gg
-      }   // end nn
-
-
-    // create matrices for group gg
-    int igg=0;
-
-    // means, SDs and covariances
-    Rcpp::NumericMatrix means_gg(VV,GG);
-    Rcpp::NumericMatrix sds_gg(VV,GG);
-    Rcpp::NumericVector weights_gg(GG);
-    Rcpp::NumericMatrix covs_gg(VV,VV*GG);
-    Rcpp::NumericMatrix XtX_gg(VV,VV*GG);
-
-    Rcpp::NumericVector rsquared(NR);
-        Rcpp::NumericVector residvar(NR);
-    Rcpp::NumericVector preds_rr(VV);
-
-    for ( int gg=0; gg<GG;gg++){
-    igg=0;
-    int ngg = ncases[gg];
-    arma::mat X=arma::zeros(ngg,VV);
-    Rcpp::NumericMatrix wgg(ngg,WW);
-    Rcpp::NumericMatrix E_gg(VV,VV);
-    for (int vv=0;vv<VV;vv++){
-        E_gg(_,vv) = E(_,vv);
-                }
-
-    for (int nn=0;nn<N;nn++){
-    if ( indcases(nn,gg) == 1){
-        for (int vv=0;vv<VV;vv++){
-          if ( ! R_IsNA(vars_index[vv] ) ){
-              X(igg,vv) = dat1( nn, vars_index[vv] );
-                        }
-                    }
-        for (int ww=0;ww<WW;ww++){
-            wgg(igg,ww) = wgt(nn,ww);
-                }
-        igg ++;
-            }
-         }
-
-    // create derived variables
-    if (NL>0){
-        for (int jj=0;jj<NL;jj++){
-        for (int nn=0;nn<ngg;nn++){
-        for (int vv=0;vv<VV;vv++){
-        if ( L(jj,vv) != 0 ){
-            X( nn, L_row_index[jj] ) += X( nn, vv ) * L( jj, vv );
-                    }
-                 }
-                }
-             }
-        }
-
-    // calculate means, variances and covaiances
-    double cbar=0;
-    double vbar=0;
-    double alpha=0;
-    double NItems=0;
-    int lli=0;
-
-    for (int ww=0;ww<WW;ww++){
-    for (int vv=0;vv<VV;vv++){
-        sds_gg(vv,gg)=0;
-        means_gg(vv,gg)=0;
-        for (int xx=0;xx<VV;xx++){
-            covs_gg(vv,xx+gg*VV)=0;
-                    }
-                }
-
-    weights_gg[gg] = 0;
-    arma::mat B_est_gg =arma::zeros(VV,VV);
-    arma::mat B_est_stand_gg =arma::zeros(VV,VV);
-
-    for (int nn=0;nn<ngg;nn++){
-        weights_gg[gg] += wgg(nn,ww);
-        for (int vv=0;vv<VV;vv++){
-           means_gg(vv,gg) += wgg(nn,ww) * X(nn,vv);
-           sds_gg(vv,gg) += wgg(nn,ww) * X(nn,vv) * X(nn,vv);
-           for (int xx=vv+1;xx<VV;xx++){
-              covs_gg( vv, xx+gg*VV) += wgg(nn,ww) * X(nn,vv) * X(nn,xx);
-                        }
-                    }
-                }
-    for (int vv=0;vv<VV;vv++){
-        means_gg(vv,gg) = means_gg( vv,gg) / weights_gg[gg];
-        sds_gg(vv,gg) = sqrt( ( sds_gg(vv,gg) - weights_gg[gg] * pow( means_gg( vv, gg), 2.0 ) )/
-                    weights_gg[gg] );
-        covs_gg(vv,vv+gg*VV) = pow( sds_gg(vv,gg), 2.0 );
-                }
-
-    for (int vv=0;vv<VV;vv++){
-           for (int xx=vv+1;xx<VV;xx++){
-             covs_gg( vv, xx+gg*VV) = covs_gg(vv,xx+gg*VV) - weights_gg[gg] * means_gg(vv,gg) * means_gg(xx,gg);
-             covs_gg( vv, xx+gg*VV) = covs_gg(vv,xx+gg*VV) / weights_gg[gg];
-             covs_gg( xx, vv+gg*VV) = covs_gg(vv,xx+gg*VV);
-                        }
-                }
-
-    // calculate Cronbach's alpha for latent variables and adjust
-    // measurement error variance
-    for (int jj=0;jj<NL;jj++){
-        NItems=0;
-        for (int vv=0;vv<VV;vv++){
-            vbar += sqrt( L(jj,vv) * L(jj,vv) ) * covs_gg( vv, vv+gg*VV);
-            if ( L(jj,vv) != 0 ){
-                NItems = NItems + 1;
-                    }
-            for (int xx=0;xx<VV;xx++){
-               if ( xx != vv ){
-                cbar += L(jj,vv) * L(jj,xx) * covs_gg( vv, xx+gg*VV);
-                        }
-                    }
-                }
-        vbar = vbar / NItems;
-        cbar = cbar / ( NItems*(NItems-1) );
-        alpha = NItems * cbar / ( vbar + ( NItems - 1 ) * cbar );
-        lli = L_row_index[jj];
-        E_gg( lli, lli ) = ( 1 - alpha ) * covs_gg( lli, lli +gg*VV);
-            }
-
-    // correction for unreliability of variances
-    for (int vv=0;vv<VV;vv++){
-        if ( unreliability[vv] > 0 ){
-             E_gg( vv, vv ) = covs_gg( vv, vv + gg*VV ) * unreliability[vv];
-                    }
-            }
-
-
-    // adjustment of covariance matrix for measurement error covariance
-    for (int vv=0;vv<VV;vv++){
-      for (int xx=0;xx<VV;xx++){
-          XtX_gg(vv,xx+gg*VV) = covs_gg( vv, xx+gg*VV) - E_gg(vv,xx);
-                }
-            }
-
-    // calculate regression coefficients
-    int nv_rr = 0;
-
-    for (int rr=0;rr<NR;rr++){
-        // int rr=2;
-
-        // select predictors
-        nv_rr=0;
-        for (int vv=0;vv<VV;vv++){
-            if ( ( R(rr,vv) != 0 ) ){
-                preds_rr[nv_rr] = vv;
-                nv_rr = nv_rr+1;
-                    }
-                }
-
-        arma::mat sigma_XX=arma::zeros(nv_rr,nv_rr);
-        arma::mat sigma_XY=arma::zeros(nv_rr,1);
-        arma::mat regr_coef_stand=arma::zeros(nv_rr,1);
-
-        for (int vv=0;vv < nv_rr; vv++){
-        for (int xx=0;xx < nv_rr; xx++){
-            sigma_XX( vv, xx ) = XtX_gg( preds_rr[vv], preds_rr[xx]+gg*VV);
-                        }
-            sigma_XY(vv,0) = XtX_gg( preds_rr[vv], R_row_index[rr]+gg*VV);
-                    }
-
-        arma::mat regr_coef = arma::mat( arma::pinv( sigma_XX ) * sigma_XY );
-        for (int vv=0; vv < nv_rr; vv ++ ){
-            regr_coef_stand(vv,0) = regr_coef(vv,0) *
-                sqrt( sigma_XX(vv,vv) ) /
-                  sqrt( XtX_gg( R_row_index[rr], R_row_index[rr]+gg*VV) );
-            B_est_gg( R_row_index[rr], preds_rr[vv] ) = regr_coef(vv,0);
-            B_est_stand_gg( R_row_index[rr], preds_rr[vv] ) = regr_coef_stand(vv,0);
-                       }
-        // calculate R-squared
-        arma::mat var_expl = arma::mat( arma::trans( regr_coef ) * sigma_XX * regr_coef );
-        rsquared[rr] = var_expl(0,0) / XtX_gg( R_row_index[rr], R_row_index[rr]+gg*VV);
-        residvar[rr] = XtX_gg( R_row_index[rr], R_row_index[rr]+gg*VV) * ( 1- rsquared[rr] );
-        }
-
-    //--- calculate parameter list
-
-    // extract coefficients
-    for (int zz=0;zz<Nrci; zz++){ // beg zz
-        parsM( zz + gg*NP, ww ) = 1;
-        parsM( zz + NP0 + gg*NP, ww ) = 1;
-        for (int hh=2;hh<Npow-1;hh++){
-        if ( ! ( R_IsNA( coeff_index(zz,hh+1) ) ) ){
-             parsM( zz + gg*NP, ww ) = parsM( zz + gg*NP, ww ) *
-                B_est_gg( coeff_index(zz,hh+1)-1, coeff_index(zz,hh)-1 );
-             parsM( zz + NP0+ gg*NP, ww ) = parsM( zz + NP0 + gg*NP, ww ) *
-                B_est_stand_gg( coeff_index(zz,hh+1)-1, coeff_index(zz,hh)-1 );
-                            }
-                    }
-        if ( ! ( R_IsNA( coeff_index(zz, 0 ) ) ) ){
-            parsM( coeff_index(zz, 0 ) - 1 + gg*NP, ww ) += parsM( zz + gg*NP, ww );
-                parsM( coeff_index(zz, 0 ) - 1 + NP0 + gg*NP, ww ) += parsM( zz + NP0+ gg*NP, ww );
-                    }
-        if ( ! ( R_IsNA( coeff_index(zz, 1 ) ) ) ){
-            parsM( coeff_index(zz, 1 ) - 1 + gg*NP, ww ) += parsM( zz + gg*NP, ww );
-                parsM( coeff_index(zz, 1 ) - 1 + NP0 + gg*NP, ww ) += parsM( zz + NP0+ gg*NP, ww );
-                    }
-            }  // end zz
-    // r squared
-    for (int rr=0;rr<NR;rr++){
-        parsM( rr + 2*NP0 + gg*NP, ww ) = rsquared[rr];
-        parsM( rr + NR + 2*NP0 + gg*NP, ww ) = residvar[rr];
-                }
-            } // end ww
-        }   // end gg
-
-    //--- output
-    return Rcpp::List::create(
-        _["parsM"] = parsM,
-        _["ncases"] = ncases,
-        _["sumwgt1"] = sumwgt1
-            );
-}
-//**********************************************************
 // Rcpp::Rcout << "sigma_XX(0,0)= " <<  sigma_XX(0,0) << " " <<
 //    "(1,1) " <<  sigma_XX(1,1)     <<  std::flush << std::endl;
 
@@ -302,8 +37,8 @@ Rcpp::NumericVector matr2vec( Rcpp::NumericMatrix matr1)
     Rcpp::NumericVector vect1(N1);
     for (int zz=0;zz<N1;zz++){
         vect1[zz] = matr1(zz,0);
-            }
-    return(vect1)    ;
+    }
+    return(vect1);
 }
 //**********************************************************
 
@@ -400,8 +135,8 @@ Rcpp::List univar_helper_multiple_V2group( Rcpp::NumericMatrix dat1,
          for (int gg=0;gg<GG;gg++){  // begin gg
              for (int hh=0;hh<WW;hh++){ // beg hh
                  mean1(vv*GG+gg,hh) = mean1vv(gg,hh) / ( sumwgt1(gg+vv*GG,hh) + eps );
-                 sd1(vv*GG+gg,hh) = sqrt( ( sd1vv(gg,hh) - sumwgt1(gg+vv*GG,hh)*
-                     pow(mean1(vv*GG+gg,hh),2) ) /( sumwgt1(gg+vv*GG,hh) - 1 ) );
+                 sd1(vv*GG+gg,hh) = std::sqrt( ( sd1vv(gg,hh) - sumwgt1(gg+vv*GG,hh)*
+                     std::pow(mean1(vv*GG+gg,hh),2) ) /( sumwgt1(gg+vv*GG,hh) - 1 ) );
             }
            } // end gg
 
@@ -694,7 +429,6 @@ Rcpp::List bifiehelpers_correl( Rcpp::NumericMatrix dat1, Rcpp::NumericVector in
                 }
             }
 
-
     // calculate covariance and correlation
     for (int zz=0;zz<ZZ;zz++){
        int vv1=itempair_index(zz,0);
@@ -730,270 +464,6 @@ Rcpp::List bifiehelpers_correl( Rcpp::NumericMatrix dat1, Rcpp::NumericVector in
 }
 //**********************************************************
 
-//**********************************************************
-// linear regression
-Rcpp::List bifiehelpers_linreg( Rcpp::NumericMatrix dat1,
-    Rcpp::NumericVector group_values, Rcpp::NumericVector dep_index,
-    Rcpp::NumericVector pre_index, Rcpp::NumericMatrix wgt,
-    Rcpp::NumericVector group_index1 )
-{
-
-    int WW = wgt.ncol();
-    int N = wgt.nrow();
-    int VV = pre_index.size();
-    int group_index = group_index1[0];
-    int GG=group_values.size();
-    int VV2=(2*VV+2)*GG;
-
-    Rcpp::NumericMatrix sumwgt1(GG,WW);
-    Rcpp::NumericVector ncases(GG);
-    Rcpp::NumericMatrix regr_coef(VV2,WW);
-    Rcpp::NumericMatrix indcases(N,GG);
-
-    //**************************
-    // extract usable cases
-    for (int nn=0;nn<N;nn++){ // beg nn
-    for (int gg=0; gg < GG; gg++ ){  // beg gg
-    if ( dat1(nn,group_index) == group_values[gg] ){
-        indcases(nn,gg)=1;
-                }
-    if (  R_IsNA( dat1(nn, dep_index[0] ) ) ){ // beg R_IsNA dep var
-        indcases(nn,gg)=0;
-                } // end R_IsNA dep var
-    for (int vv=0;vv<VV;vv++){ // beg vv  independent vars
-       if (  R_IsNA( dat1(nn, pre_index[vv] ) ) ){
-        indcases(nn,gg)=0;
-                }
-            } // end vv  independent vars
-        if ( indcases(nn,gg) == 1 ){
-            ncases[gg] ++;
-            for (int ww=0;ww<WW; ww++){
-                sumwgt1(gg,ww) += wgt(nn,ww);
-                    }
-            break;
-                }
-        }   // end gg
-  }   // end nn
-
-
-    double sig2=0;
-    double sig2a=0;
-
-    for (int gg=0;gg<GG;gg++){
-    int igg=0;
-
-    // create design matrices
-    int ngg = ncases[gg];
-    arma::mat X0=arma::zeros( ngg, VV );
-    arma::mat X=arma::zeros( ngg, VV );
-    arma::colvec y0=arma::zeros( ngg );
-    arma::colvec y=arma::zeros( ngg );
-    arma::mat wgt0=arma::zeros( ngg, WW);
-
-    Rcpp::NumericMatrix M_pre(VV,WW);
-    Rcpp::NumericMatrix SD_pre(VV,WW);
-    Rcpp::NumericMatrix M_dep(1,WW);
-    Rcpp::NumericMatrix SD_dep(1,WW);
-
-    //***** define input matrices
-    for (int nn=0;nn < N; nn++){  // beg nn
-        if ( indcases(nn,gg)==1){  // beg indcases gg
-            y0(igg,0) = dat1(nn, dep_index[0] );
-            for (int vv=0;vv<VV;vv++){  // beg vv
-               X0(igg,vv) = dat1(nn,pre_index[vv] );
-                    }  // end vv
-            igg ++;
-            } // end if indcases gg
-          } // end nn
-
-    //**** define used matrices
-    double wtmp=0;
-
-    for ( int ww=0; ww <WW; ww++){ // beg ww
-    igg=0;
-    for (int nn=0;nn < N; nn++){  // beg nn
-        if ( indcases(nn,gg)==1){  // beg indcases gg
-            wgt0(igg,ww) = wgt(nn,ww);
-            wtmp = sqrt( wgt(nn,ww));
-            y(igg,0) = y0(igg,0)*wtmp;
-            M_dep(0,ww) += y0(igg,0) * wgt(nn,ww);
-            SD_dep(0,ww) += y0(igg,0) * y0(igg,0) * wgt(nn,ww);
-            for (int vv=0;vv<VV;vv++){  // beg vv
-               X(igg,vv) = X0(igg, vv )*wtmp;
-               M_pre(vv,ww) += X0(igg,vv) * wgt(nn,ww);
-               SD_pre(vv,ww) += X0(igg,vv) * X0(igg,vv) * wgt(nn,ww);
-                    }  // end vv
-            igg ++;
-            } // end if indcases gg
-          } // end nn
-
-    //*** fit linear model
-    arma::colvec coef = arma::solve(X, y);      // fit model y ~ X
-    // arma::colvec resid = y - X*coef;            // residuals
-    // not that the weights are already included in the residual calculation
-    arma::colvec resid(ngg);
-    for (int hh=0;hh<ngg;hh++){
-        resid(hh,0) = y0(hh,0);
-        for (int vv=0;vv<VV;vv++){
-           resid(hh,0) = resid(hh,0) - X0(hh,vv) * coef(vv,0);
-            }
-    }
-
-    // sig2 = arma::as_scalar( arma::trans(resid)*resid );
-    sig2=0;
-    for (int hh=0;hh<ngg;hh++){
-          sig2 += pow( resid(hh,0),2.0) * wgt0(hh,ww);
-       }
-    double sggww = sumwgt1(gg,ww);
-    sig2a = sig2 / ( sggww - VV );
-
-    // collect all regression coefficients
-    // unstandardized coefficients
-    for (int vv=0;vv<VV;vv++){
-        regr_coef( vv + gg*(2*VV+2), ww ) = coef(vv,0);
-            }
-    regr_coef( VV + gg*(2*VV+2), ww ) = sqrt( sig2a );  // sigma
-    // compute R^2
-    M_dep(0,ww) = M_dep(0,ww) / sggww;
-    double sig3 = SD_dep(0,ww) - sggww * pow( M_dep(0,ww), 2.0);
-    SD_dep(0,ww) = sqrt( sig3 / ( sggww - 1 ) );
-    regr_coef( VV+1 + gg*(2*VV+2), ww ) = 1 - sig2 / sig3;
-
-    // compute standardized coefficients
-    for (int vv=0;vv<VV;vv++){
-        M_pre(vv,ww) = M_pre(vv,ww) / sggww;
-        SD_pre(vv,ww) = SD_pre(vv,ww) - sggww *  pow( M_pre(vv,ww), 2.0);
-        SD_pre(vv,ww) = sqrt( SD_pre(vv,ww) / ( sggww - 1 ) );
-        regr_coef( VV+2+vv + gg*(2*VV+2), ww ) =
-           coef(vv,0) / SD_dep(0,ww) * SD_pre(vv,ww);
-                }
-    } // end ww
-    } // end gg
-
-    return Rcpp::List::create(
-        _["ncases"] = ncases,
-        _["sumwgt1"] = sumwgt1,
-        _["regr_coef"] = regr_coef
-    );
-}
-//**********************************************************
-
-
-//**********************************************************
-// BIFIE helpers Wald test
-Rcpp::List bifiehelpers_waldtest( int VV, Rcpp::NumericVector Ccols,
-    Rcpp::NumericMatrix parsM, Rcpp::NumericMatrix parsrepM,
-    int ii, int RR, Rcpp::NumericVector fayfac,
-    arma::mat ACdes, arma::colvec Ardes )
-{
-
-    //@@fayfac
-    int NF = fayfac.size();
-    double f1=0;
-        //--
-
-    //*** calculate covariance matrix for imputation ii
-    arma::mat var_w = arma::zeros(VV,VV);
-    for (int vv1=0;vv1<VV;vv1++){
-    for (int vv2=vv1;vv2<VV;vv2++){
-       //@@fayfac
-       f1 = fayfac[0];
-       //--
-    for (int rr=0;rr<RR;rr++){
-       //@@fayfac
-       if (NF>1){
-            f1 = fayfac[rr];
-              }
-       //--
-       var_w(vv1,vv2) += f1 * ( parsrepM( Ccols[vv1], rr+ii*RR ) - parsM( Ccols[vv1], ii ) )*
-            ( parsrepM( Ccols[vv2], rr+ii*RR ) - parsM( Ccols[vv2], ii ) );
-                }
-    // var_w(vv1,vv2) = var_w(vv1,vv2);
-    var_w(vv2,vv1) = var_w(vv1,vv2);
-                }
-            }
-
-    //***  compute chi squared Wald test statistic
-    // compute covariance matrix of hypothesis
-    arma::mat var_hyp = arma::mat( ACdes * var_w * trans( ACdes) );
-
-    // compute inverse of variance matrix of hypothesis
-    arma::mat var_hypinv = arma::inv( var_hyp );
-    // parameter vector
-    arma::colvec parm_vec= arma::zeros(VV,1);
-    for (int vv=0;vv<VV;vv++){
-        parm_vec(vv,0) = parsM( Ccols[vv], ii );
-                }
-    // hypothesis statistic
-    arma::mat hyp_stat = arma::mat( ACdes * parm_vec - Ardes );
-    arma::mat chi2 = arma::mat( trans( hyp_stat ) * var_hypinv * hyp_stat );
-
-    return Rcpp::List::create(
-        _["chi2"] = chi2,
-        _["var_w"] = var_w
-        );
-}
-//**********************************************************
-
-
-//**********************************************************
-// BIFIE helpers Wald test
-Rcpp::List bifiehelpers_waldtest_vcov( int VV, Rcpp::NumericVector Ccols,
-    Rcpp::NumericMatrix parsM, Rcpp::NumericMatrix parsrepM,
-    int ii, int RR, Rcpp::NumericVector fayfac,
-    arma::mat ACdes, arma::colvec Ardes )
-{
-
-    //@@fayfac
-    int NF = fayfac.size();
-    double f1=0;
-        //--c
-
-    //*** calculate covariance matrix for imputation ii
-    arma::mat var_w = arma::zeros(VV,VV);
-    for (int vv1=0;vv1<VV;vv1++){
-    for (int vv2=vv1;vv2<VV;vv2++){
-       //@@fayfac
-       f1 = fayfac[0];
-       //--
-    for (int rr=0;rr<RR;rr++){
-          //@@fayfac
-          if (NF>1){
-             f1 = fayfac[rr];
-                 }
-          //--
-       var_w(vv1,vv2) += f1 * ( parsrepM( Ccols[vv1], rr+ii*RR ) - parsM( Ccols[vv1], ii ) )*
-            ( parsrepM( Ccols[vv2], rr+ii*RR ) - parsM( Ccols[vv2], ii ) );
-                }
-//    var_w(vv1,vv2) = fayfac[0] * var_w(vv1,vv2);
-    var_w(vv2,vv1) = var_w(vv1,vv2);
-                }
-            }
-
-    //***  compute chi squared Wald test statistic
-    // compute covariance matrix of hypothesis
-    arma::mat var_hyp = arma::mat( ACdes * var_w * trans( ACdes) );
-
-    // compute inverse of variance matrix of hypothesis
-    arma::mat var_hypinv = arma::mat( var_hyp );
-    // parameter vector
-    arma::colvec parm_vec= arma::zeros(VV,1);
-    for (int vv=0;vv<VV;vv++){
-        parm_vec(vv,0) = parsM( Ccols[vv], ii );
-                }
-    // hypothesis statistic
-    arma::mat hyp_stat = arma::mat( ACdes * parm_vec - Ardes );
-    arma::mat chi2 = arma::mat( trans( hyp_stat ) * var_hypinv * hyp_stat );
-
-    // int df=ACdes.n_rows;
-    return Rcpp::List::create(
-        _["chi2"] = chi2,
-        _["var_w"] = var_w,
-        _["var_hyp"] = var_hyp,
-        _["hyp_stat"] = hyp_stat
-        );
-}
-//**********************************************************
 
 //**********************************************************
 // etasquared and d statistics
